SED_tools
=======
A python package for Sound Event Detection post-processing and optimization

Documentation
-------------
See http://aeseg.github.io/ for a complete reference manual and introductory tutorials.


Demonstration notebooks
-----------------------
What does sed_tools do?  Here are some quick demonstrations:


Installation
------------

sed_tools is currently under development and is available on test PyPI. You can install it by running

```
pip install -i https://test.pypi.org/simple/ aeseg
```
